function [Nlist, jlist] = Phase1_p5(IPARAM,MCPARAM,LIK,struc)
% first phase of MCMC - used to speed up the main phase

burnin=0.5;
Nlist=[];

% get starting values (drawn from priors) - starting vals for the
% parameters must give a non-zero density.
% NOTE HERE- MAY NEED TO ADJUST THIS FUNCTION or starting vals may not be
% found
[rec_start jlist] = find_Ph1_starts_p5(struc,IPARAM,MCPARAM,LIK);
save rec_start rec_start

for h=1:MCPARAM.N_markov
    
    %draw starting values
    Olist=[]; %storage for each Markov chain
    
    theta=rec_start(h,1:5);
    for i=1:MCPARAM.m %loop over m
        showme=[h i]
        

        %basic Metropolis algorithm:
        for k=1:length(theta) %loop over parameters
            ThetaStar=theta;
            
            switch k %propose nw theta from jumping distr.
                case 1
                    ThetaStar(1)=log(ThetaStar(1));
                    ThetaKStar=randn*0.05+ThetaStar(1);
                    ThetaStar(1)=ThetaKStar;
                    ThetaStar(1)=exp(ThetaStar(1));
                    ThetaStar(1)=max(ThetaStar(1),0.0001); % zero will crash genDe
                case 2
                    ThetaStar(2)=log(ThetaStar(2));
                    ThetaKStar=randn*0.15+ThetaStar(2);
                    ThetaStar(2)=ThetaKStar;
                    ThetaStar(2)=exp(ThetaStar(2));
                    ThetaStar(2)=max(ThetaStar(2),0.0001); % zero will crash genDe
                case 3
                    ThetaStar(3)=log(ThetaStar(3)/(1-ThetaStar(3))); %logit transform
                    ThetaKStar=randn*0.10+ThetaStar(3);
                  
                    ThetaStar(3)=ThetaKStar;
                    ThetaStar(3)=exp(ThetaStar(3))./(1+exp(ThetaStar(3))); %inverse logit transform
                    ThetaStar(3)=min(ThetaStar(3),0.9999999999); ThetaStar(3)=max(ThetaStar(3),0.0000000001); %cannot logit 0 or 1 
                case 4
                    ThetaStar(4)=log(ThetaStar(4));
                    ThetaKStar=randn*0.10+ThetaStar(4);
                    ThetaStar(4)=ThetaKStar;
                    ThetaStar(4)=exp(ThetaStar(4));
                    ThetaStar(4)=max(ThetaStar(4),0.0001);
                case 5
                    ThetaStar(5)=log(ThetaStar(5));
                    ThetaKStar=randn*0.10+ThetaStar(5);
                    ThetaStar(5)=ThetaKStar;
                    ThetaStar(5)=exp(ThetaStar(5));
                    ThetaStar(5)=max(ThetaStar(5),0.0001);
            end

            IPARAM.a=ThetaStar(4);
            IPARAM.b=ThetaStar(5);
            %simulate a De dataset for the same size aliquots
            %if length(struc.de_isize(:,1))>1
                
                delist2=[];
                for i5=1:length(struc.de_isize(:,1))
                    IPARAM.isize=struc.de_isize(i5,1);
                    IPARAM.na=struc.de_isize(i5,2);                
                    tempde = genDe_R1_lin(IPARAM,ThetaStar,struc);
                    delist2=[delist2; tempde];
                end
            %else
            %    IPARAM.isize=struc.de_isize;
            %    IPARAM.na=length(struc.de(:,1));
            %    delist2 = genDe_R1_lin(IPARAM,ThetaStar,struc);
            %end

            %find P(Y|X), where Y is the measured MAM3, and X is the modelled
            %parameters
            de_sorted=sortrows(delist2);
            startval=getWAV(de_sorted(1:ceil(length(de_sorted(:,1))*0.15),:));            
            CAM=getCAM(delist2);
            
            switch struc.mamflag
                case 1
                    MAM3=getmam3(delist2,IPARAM.sigb(1),startval);
                case 2
                    MAM3=getmam3ul(delist2,IPARAM.sigb(1),startval);
            end
            
            
            T(1,1) = interp1(LIK.MA(:,1),LIK.MA(:,2),MAM3(1));
            T(1,2) = interp1(LIK.SIG(:,1),LIK.SIG(:,2),MAM3(3));
            T(1,3) = interp1(LIK.P(:,1),LIK.P(:,2),MAM3(4));
            T(1,4) = interp1(LIK.CAM(:,1),LIK.CAM(:,2),CAM(1));
            ind=find(isnan(T));
            T(ind)=0;
            
            priors(1)=evalprior(struc.prior.burial,ThetaStar(1));
            priors(2)=evalprior(struc.prior.sd2,ThetaStar(2));
            priors(3)=evalprior(struc.prior.p,ThetaStar(3));
            priors(4)=evalprior(struc.prior.A,ThetaStar(4));
            priors(5)=evalprior(struc.prior.B,ThetaStar(5));
            
            ind=find(isnan(priors));
            priors(ind)=0;
            
            densThetaStar=prod(T([1 2 3 4]))*prod(priors); %posterior density
                                
            if i==1
                theta=ThetaStar;
                densTheta=densThetaStar;
                acc=0;
                rej=0;
            else
                %will never accept a zero density solution, provided the
                %starting point is non-zero density
                r=densThetaStar/densTheta;
                R2=rand;
                if R2<min(r,1)
                    theta=ThetaStar;
                    densTheta=densThetaStar;
                    acc=acc+1;
                else
                    rej=rej+1;
                end
            end
        end

        temp=[theta densTheta]
        Olist=[Olist; temp];
    end
    templist=Olist(ceil(MCPARAM.m*burnin):MCPARAM.m,:);
    Nlist=[Nlist; templist];
end